﻿using System;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9572
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;
            map.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColors.White);

            var layerOverlay = new LayerOverlay();
            var uri = new Uri("https://services.sandre.eaufrance.fr/geo/zrpe");

            var wmsRasterLayer = new customWMSLayer(uri);
            wmsRasterLayer.ActiveLayerNames.Add("ZoneVuln_com_FXX");
            wmsRasterLayer.Crs = "EPSG:3857";
            wmsRasterLayer.OutputFormat = "image/png";
            wmsRasterLayer.Parameters.Add("EXCEPTIONS", "xml");
            wmsRasterLayer.Parameters.Add("TRANSPARENT", "TRUE");
            wmsRasterLayer.ActiveStyleNames.Add("default");

            wmsRasterLayer.Proj4 = new Proj4Projection(4326, 3857);

            layerOverlay.Layers.Add("ZoneVul", wmsRasterLayer);
            map.Overlays.Add(layerOverlay);
            wmsRasterLayer.Open();
            map.CurrentExtent = wmsRasterLayer.GetBoundingBox();
            map.Refresh();
        }
    }

    public class customWMSLayer : WmsRasterLayer
    {
        private Proj4Projection proj4 = null;
        private RectangleShape defaultExtent = new RectangleShape(-180, 90, 180, -90);

        public customWMSLayer(Uri uri) : base(uri)
        { }

        public Proj4Projection Proj4 { get => proj4; set => proj4 = value; }

        protected override RectangleShape GetBoundingBoxCore()
        {
            RectangleShape boudingBox = defaultExtent;

            if (proj4 != null)
            {
                proj4.Open();

                boudingBox = proj4.ConvertToExternalProjection(defaultExtent);

                proj4.Close();
            }

            return boudingBox;
        }

    }

}
